@@ -5,6 +5,8 @@
 // WebP image format support
 //
 
+#include "common.h"
+
 #include <cairo/cairo.h>
 #include <stdint.h>
 #include <stdio.h>
@@ -14,22 +16,16 @@
 // WebP signature
 static const uint8_t signature[] = { 'R', 'I', 'F', 'F' };
 
-/**
- * Apply alpha to color.
- * @param[in] alpha alpha channel value
- * @param[in] color color value
- * @return color with applied alpha
- */
-static uint8_t multiply_alpha(uint8_t alpha, uint8_t color)
-{
-    const uint16_t temp = (alpha * color) + 0x80;
-    return ((temp + (temp >> 8)) >> 8);
-}
-
 // WebP loader implementation
 cairo_surface_t* load_webp(const uint8_t* data, size_t size, char* format,
                            size_t format_sz)
 {
+    cairo_surface_t* surface = NULL;
+    uint8_t* sdata;
+    size_t stride;
+    WebPBitstreamFeatures prop;
+    VP8StatusCode status;
+
     // check signature
     if (size < sizeof(signature) ||
         memcmp(data, signature, sizeof(signature))) {
@@ -37,21 +33,16 @@ cairo_surface_t* load_webp(const uint8_t* data, size_t size, char* format,
     }
 
     // get image properties
-    WebPBitstreamFeatures prop;
-    VP8StatusCode status = WebPGetFeatures(data, size, &prop);
+    status = WebPGetFeatures(data, size, &prop);
     if (status != VP8_STATUS_OK) {
         fprintf(stderr, "Unable to get WebP image properties: status %i\n",
                 status);
         return NULL;
     }
 
-    // create image instance
-    const cairo_format_t fmt =
-        prop.has_alpha ? CAIRO_FORMAT_ARGB32 : CAIRO_FORMAT_RGB24;
-    cairo_surface_t* surface =
-        cairo_image_surface_create(fmt, prop.width, prop.height);
-    if (cairo_surface_status(surface) != CAIRO_STATUS_SUCCESS) {
-        fprintf(stderr, "Unable to create surface\n");
+    // prepare surface and metadata
+    surface = create_surface(prop.width, prop.height, prop.has_alpha);
+    if (!surface) {
         return NULL;
     }
     snprintf(format, format_sz, "WebP %s %s%s",
@@ -59,10 +50,10 @@ cairo_surface_t* load_webp(const uint8_t* data, size_t size, char* format,
              prop.has_alpha ? "+alpha" : "",
              prop.has_animation ? "+animation" : "");
 
-    uint8_t* dst_data = cairo_image_surface_get_data(surface);
-    const size_t stride = cairo_image_surface_get_stride(surface);
-    const size_t len = stride * prop.height;
-    if (!WebPDecodeBGRAInto(data, size, dst_data, len, stride)) {
+    // decode image
+    sdata = cairo_image_surface_get_data(surface);
+    stride = cairo_image_surface_get_stride(surface);
+    if (!WebPDecodeBGRAInto(data, size, sdata, stride * prop.height, stride)) {
         fprintf(stderr, "Error decoding WebP\n");
         cairo_surface_destroy(surface);
         return NULL;
@@ -70,14 +61,7 @@ cairo_surface_t* load_webp(const uint8_t* data, size_t size, char* format,
 
     // handle transparency
     if (prop.has_alpha) {
-        for (size_t i = 0; i < len; i += 4 /* argb */) {
-            const uint8_t alpha = dst_data[i + 3];
-            if (alpha != 0xff) {
-                dst_data[i + 0] = multiply_alpha(alpha, dst_data[i + 0]);
-                dst_data[i + 1] = multiply_alpha(alpha, dst_data[i + 1]);
-                dst_data[i + 2] = multiply_alpha(alpha, dst_data[i + 2]);
-            }
-        }
+        apply_alpha(surface);
     }
 
     cairo_surface_mark_dirty(surface);
