@@ -12,7 +12,7 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <sys/time.h>
+#include <time.h>
 
 /** Viewer context. */
 typedef struct {
@@ -169,10 +169,16 @@ static void on_redraw(cairo_surface_t* window)
 
     // image meta information: file name, format, exif, etc
     if (config.show_info) {
-        char scale[8];
-        snprintf(scale, sizeof(scale), "%i%%",
+        char text[32];
+        snprintf(text, sizeof(text), "%i%%",
                  (int)(viewer.canvas.scale * 100.0));
-        draw_text(cairo, 10, get_window_height() - 30, scale);
+        draw_text(cairo, 10, get_window_height() - 30, text);
+        if (viewer.file_list.total > 1) {
+            const int len =
+                snprintf(text, sizeof(text), "%lu of %lu",
+                         viewer.file_list.current + 1, viewer.file_list.total);
+            draw_text(cairo, get_window_width() - 10 - len * 10, 10, text);
+        }
         draw_lines(cairo, 10, 10, (const char**)viewer.image->meta);
     }
 
@@ -263,10 +269,10 @@ bool run_viewer(const char** files, size_t total)
                                        .on_keyboard = on_keyboard };
     // create unique application id
     char app_id[64];
-    struct timeval tv;
-    gettimeofday(&tv, NULL);
+    struct timespec ts;
+    clock_gettime(CLOCK_MONOTONIC, &ts);
     snprintf(app_id, sizeof(app_id), APP_NAME "_%lx",
-             tv.tv_sec << 32 | tv.tv_usec);
+             (ts.tv_sec << 32) | ts.tv_nsec);
 
     // setup window position via Sway IPC
     const int ipc = sway_connect();
